@@ -85,6 +85,21 @@ def test_plugin_stat_with_groups():
         '--infectors', 'A0', '--plugin', 'stat', '--interval', '1'
     ])
 
+def test_plugin_init():
+    main([
+        '--jobs', '1', '--repeats', '100', '--plugin', 'init', '--at', '0',
+        '--incidence-rate', '0.01'
+    ])
+    main([
+        '--jobs', '1', '--repeats', '100', '--popsize', 'A=100', 'B=200', '--plugin',
+        'init', '--at', '0', '--incidence-rate', '1', 'A=0.01', 'B=0.02', '--leadtime', 'any'
+    ])
+    main([
+        '--jobs', '1', '--repeats', '100', '--popsize', 'A=100', 'B=200', '--plugin',
+        'init', '--at', '0', '--incidence-rate', '1', 'A=0.01', 'B=0.02',
+        '--seroprevalence', '1', 'A=0.02', 'B=0.04', '--leadtime', 'asymptomatic'
+    ])
+
 
 def test_plugin_sample():
     main([
@@ -139,6 +154,26 @@ def test_plugin_insert():
     ])
 
 
+def test_plugin_remove():
+    main([
+        '--jobs', '1', '--repeats', '100', '--stop-if', 't>10', '--plugin',
+        'remove', '2', '--at', '1'
+    ])
+    main([
+        '--jobs', '1', '--repeats', '100', '--popsize', 'A=100', 'B=100', '--stop-if', 't>10', '--plugin',
+        'remove', 'A=2', '--interval', '1'
+    ])
+
+def test_plugin_community_spread():
+    main([
+        '--jobs', '1', '--repeats', '100', '--stop-if', 't>10', '--plugin',
+        'community_spread', '--probability', '0.0001', '--interval', '1'
+    ])
+    main([
+        '--jobs', '1', '--repeats', '100', '--popsize', 'A=100', 'B=200', '--stop-if', 't>10', '--plugin',
+        'community_spread', '--probability', '1', 'A=0.0001', '--interval', '1'
+    ])
+
 def test_plugin_insert_hetero_pop():
     main([
         '--jobs', '1', '--repeats', '100', '--stop-if', 't>10', '--popsize',
